package com.dgtis.dorm.manager.db.dao;

import java.util.List;
import java.util.Map;

import com.dgtis.dorm.manager.db.domain.AlumniUserMessage;
import org.apache.ibatis.annotations.Param;

public interface AlumniUserMessageMapper {
    int deleteByPrimaryKey(Integer id);

    int insert(AlumniUserMessage record);

    int insertSelective(AlumniUserMessage record);

    AlumniUserMessage selectByPrimaryKey(Integer id);

    int updateByPrimaryKeySelective(AlumniUserMessage record);

    int updateByPrimaryKey(AlumniUserMessage record);
    
    List<Map> selectUserMessageAll(AlumniUserMessage record);

	List<Map> selectUserMessage(AlumniUserMessage record);

	List<Map> selectSystemUserMessageByUserId(@Param("userId") String userId);

	List<Map> selectUserMessageDetails(@Param("userId") String userId, @Param("fromUserId") String fromUserId);

	void updateUserMessageRead(@Param("userId") String userId, @Param("fromUserId") String fromUserId);

	Integer selectPrivateNoReadCount(@Param("userId")String userId);

	/**
	 * 查询申请加入圈子状态为待审核的用户数量
	 * @param userId
	 * @return
	 */
	Integer selectNoNormalCountByAOU(@Param("userId") String userId);

	/**
	 * 查询我的系统未读消息
	 * @param userId
	 * @return
	 */
    Integer findMyMsgCount(@Param("userId") String userId);

	Integer updateMsg(@Param(value = "id") String id);
}